@@ -4,7 +4,7 @@ import json
 import pandas as pd
 import requests as req
 import jsonpath
-from PaHKStockXueQiuFinanceData.common import *
+from jquote_api.common import *
 
 def _get_pagedata(freq='q', code='00700', page=8):
     # 获取雪球页面财务数据
